Scene Components
================

.. autoclass:: yt_idv.scene_components.base_component.SceneComponent
.. autoclass:: yt_idv.scene_components.blocks.BlockRendering
.. autoclass:: yt_idv.scene_components.octree_blocks.OctreeBlockRendering
.. autoclass:: yt_idv.scene_components.mesh.MeshRendering
.. autoclass:: yt_idv.scene_components.rgba.RGBADisplay
.. autoclass:: yt_idv.scene_components.rgba.RGBALinePlot
.. autoclass:: yt_idv.scene_components.curves.CurveRendering
.. autoclass:: yt_idv.scene_components.curves.CurveCollectionRendering
